﻿using System;
using Infragistics;
using MonoTouch.UIKit;

namespace CustomDataSource_Xamarin
{
	public class RowColumnReversedDataSourceHelper : IGGridViewDataSourceHelper
	{
		public RowColumnReversedDataSourceHelper ()
		{
		}

		// the number of columns in this case will be the number of rows for a normal grid (since we are flipping the two).
		public override int NumberOfColumns (IGGridView gridView)
		{
			return this.Data.Length;
		}

		// And similarly the nubmer of rows in this case will be the number of columns in a normal grid
		public override int NumberOfRowsInSection (IGGridView gridView, int section)
		{
			return this.Columns.Length;
		}

		// Since we are flipping the columns and the rows when we want this method call to flip them for us
		public override IGCellPath NormalizePath (IGCellPath path)
		{
			return new IGCellPath (path.ColumnIndex, path.SectionIndex, path.RowIndex);
		}

		// And this reverses the change made in normalizePath.
		public override IGCellPath DenormalizePath (IGCellPath path)
		{
			return new IGCellPath (path.ColumnIndex, path.SectionIndex, path.RowIndex);
		}

		// in this case there are no titles for the header column, return an empty string.
		public override string TitleForHeaderInColumn (IGGridView gridView, int column)
		{
			return "";
		}

		// We will use the fixed left column to hold the column headers now moved to be row headers.  So mark a single column as fixed.
		public override int NumberOfFixedLeftColumns (IGGridView gridView)
		{
			return 1;
		}

		// When the fixed column cells are being rendered, we will want to take control of that process to show the row headers for the row.  We will put the column header text into the cell.
		public override IGGridViewCell CreateFixedLeftCell (IGGridView gridView, IGCellPath path)
		{
			IGGridViewCell c = (IGGridViewCell) gridView.DequeueReusableCell ("fc");
			if (c == null) {
				c = new IGGridViewCell ("fc");
			}
			string columnHeader = ((IGGridViewColumnDefinition)this.Columns [path.RowIndex]).HeaderText;
			c.TextLabel.Text = columnHeader;
			c.BackgroundColor = UIColor.Green;
			return c;
		}

		// We created a custom headerCell to show the image of the person whose data is being displayed.  Override this method to get the data
		public override IGGridViewHeaderCell CreateHeaderCell (IGGridView gridView, int column)
		{
			MyCustomHeaderCellWithImageCell hc =(MyCustomHeaderCellWithImageCell) gridView.DequeueReusableCell ("hc");

			if (hc == null) {
				hc = new MyCustomHeaderCellWithImageCell ("hc");
			}
			// Gets the "real" row of data from the data source
			IGCellPath path = new IGCellPath (0, 0, column);
			path = this.DenormalizePath (path);

			// then gets the data object
			IGSalesmanItem item = (IGSalesmanItem)this.Data [path.RowIndex];

			// and finds the image associated with that data object.
			hc.Image = item.Image;

			return hc;
		}
	}
}

